######
crypto
######


.. code-block:: python

    from mitm import crypto

.. automodule:: mitm.crypto

----

.. automethod:: mitm.crypto.new_RSA

.. automethod:: mitm.crypto.new_X509

----

.. autodata:: mitm.crypto.LRU_MAX_SIZE
    :annotation:

.. autoclass:: mitm.crypto.CertificateAuthority
    :members:
